@@ -10,12 +10,21 @@ import torch.nn as nn
 from mmcv import color_val
 from mmcv.utils import print_log
 
+# TODO import `auto_fp16` from mmcv and delete them from mmcls
+try:
+    from mmcv.runner import auto_fp16
+except ImportError:
+    warnings.warn('auto_fp16 from mmcls will be deprecated.'
+                  'Please install mmcv>=1.1.4.')
+    from mmcls.core import auto_fp16
+
 
 class BaseClassifier(nn.Module, metaclass=ABCMeta):
     """Base class for classifiers"""
 
     def __init__(self):
         super(BaseClassifier, self).__init__()
+        self.fp16_enabled = False
 
     @property
     def with_neck(self):
@@ -70,6 +79,7 @@ class BaseClassifier(nn.Module, metaclass=ABCMeta):
         else:
             raise NotImplementedError('aug_test has not been implemented')
 
+    @auto_fp16(apply_to=('img', ))
     def forward(self, img, return_loss=True, **kwargs):
         """
         Calls either forward_train or forward_test depending on whether
