@@ -1,6 +1,10 @@
 from .channel_shuffle import channel_shuffle
 from .inverted_residual import InvertedResidual
 from .make_divisible import make_divisible
+from .mixup import BatchMixupLayer
 from .se_layer import SELayer
 
-__all__ = ['channel_shuffle', 'make_divisible', 'InvertedResidual', 'SELayer']
+__all__ = [
+    'channel_shuffle', 'make_divisible', 'InvertedResidual', 'BatchMixupLayer',
+    'SELayer'
+]
